@@ -1,6 +1,6 @@
 package Pithub;
 BEGIN {
-  $Pithub::VERSION = '0.01005';
+  $Pithub::VERSION = '0.01006';
 }
 
 # ABSTRACT: Github v3 API
@@ -15,30 +15,38 @@ use Pithub::Repos;
 use Pithub::Users;
 extends 'Pithub::Base';
 
+
+
 sub gists {
     return shift->_create_instance('Pithub::Gists');
 }
 
+
 sub git_data {
     return shift->_create_instance('Pithub::GitData');
 }
 
+
 sub issues {
     return shift->_create_instance('Pithub::Issues');
 }
 
+
 sub orgs {
     return shift->_create_instance('Pithub::Orgs');
 }
 
+
 sub pull_requests {
     return shift->_create_instance('Pithub::PullRequests');
 }
 
+
 sub repos {
     return shift->_create_instance('Pithub::Repos');
 }
 
+
 sub users {
     return shift->_create_instance('Pithub::Users');
 }
@@ -55,7 +63,7 @@ Pithub - Github v3 API
 
 =head1 VERSION
 
-version 0.01005
+version 0.01006
 
 =head1 SYNOPSIS
 
@@ -76,6 +84,43 @@ version 0.01005
         printf "%s\n", $row->{name};
     }
 
+=head1 DESCRIPTION
+
+L<Pithub> provides a set of modules to access the
+L<Github v3 API|http://developer.github.com/v3/> in an object
+oriented way. There is also L<Net::Github> does the same for the
+older versions of the API. L<Pithub> supports all API calls so far.
+
+=head1 METHODS
+
+=head2 gists
+
+Provides access to L<Pithub::Gists>.
+
+=head2 git_data
+
+Provides access to L<Pithub::GitData>.
+
+=head2 issues
+
+Provides access to L<Pithub::Issues>.
+
+=head2 orgs
+
+Provides access to L<Pithub::Orgs>.
+
+=head2 pull_requests
+
+Provides access to L<Pithub::PullRequests>.
+
+=head2 repos
+
+Provides access to L<Pithub::Repos>.
+
+=head2 users
+
+Provides access to L<Pithub::Users>.
+
 =head1 DOCUMENTATION
 
 Quite a lot of the L<Pithub> documentation has been taken directly
@@ -93,6 +138,17 @@ that it's possible that the API will change. This applies to
 L<Pithub> itself as well as the
 L<Github v3 API|http://developer.github.com/v3/>.
 
+=head1 CONTRIBUTE
+
+This module is hosted on L<Github|https://github.com/plu/Pithub>, so
+feel free to fork it and send pull requests.
+There are two different kinds of test suites, one is just checking
+the HTTP requests that are created by the method calls, without
+actually sending them. The second one is sending real requests to
+the Github API. If you want to contribute to this project, I highly
+recommend to run the live tests on a test account, because it will
+generate a lof of activity.
+
 =head1 MODULES
 
 There are different ways of using the Pithub library. You can either
