@@ -1,6 +1,6 @@
 package Pithub::Issues;
 BEGIN {
-  $Pithub::Issues::VERSION = '0.01005';
+  $Pithub::Issues::VERSION = '0.01006';
 }
 
 # ABSTRACT: Github v3 Issues API
@@ -13,22 +13,11 @@ use Pithub::Issues::Labels;
 use Pithub::Issues::Milestones;
 extends 'Pithub::Base';
 
+
 sub comments {
     return shift->_create_instance('Pithub::Issues::Comments');
 }
 
-sub events {
-    return shift->_create_instance('Pithub::Issues::Events');
-}
-
-sub labels {
-    return shift->_create_instance('Pithub::Issues::Labels');
-}
-
-sub milestones {
-    return shift->_create_instance('Pithub::Issues::Milestones');
-}
-
 
 sub create {
     my ( $self, %args ) = @_;
@@ -42,6 +31,11 @@ sub create {
 }
 
 
+sub events {
+    return shift->_create_instance('Pithub::Issues::Events');
+}
+
+
 sub get {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: issue_id' unless $args{issue_id};
@@ -54,6 +48,11 @@ sub get {
 }
 
 
+sub labels {
+    return shift->_create_instance('Pithub::Issues::Labels');
+}
+
+
 sub list {
     my ( $self, %args ) = @_;
     $self->_get_user_repo_args( \%args );
@@ -72,6 +71,11 @@ sub list {
 }
 
 
+sub milestones {
+    return shift->_create_instance('Pithub::Issues::Milestones');
+}
+
+
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: issue_id' unless $args{issue_id};
@@ -95,10 +99,14 @@ Pithub::Issues - Github v3 Issues API
 
 =head1 VERSION
 
-version 0.01005
+version 0.01006
 
 =head1 METHODS
 
+=head2 comments
+
+Provides access to L<Pithub::Issues::Comments>.
+
 =head2 create
 
 =over
@@ -227,6 +235,10 @@ Response: C<< Status: 201 Created >>
 
 =back
 
+=head2 events
+
+Provides access to L<Pithub::Issues::Events>.
+
 =head2 get
 
 =over
@@ -322,6 +334,10 @@ Response: C<< Status: 200 OK >>
 
 =back
 
+=head2 labels
+
+Provides access to L<Pithub::Issues::Labels>.
+
 =head2 list
 
 =over
@@ -702,6 +718,10 @@ Response: C<< Status: 200 OK >>
 
 =back
 
+=head2 milestones
+
+Provides access to L<Pithub::Issues::Milestones>.
+
 =head2 update
 
 =over
