@@ -1,6 +1,6 @@
 package Pithub::Orgs;
 BEGIN {
-  $Pithub::Orgs::VERSION = '0.01005';
+  $Pithub::Orgs::VERSION = '0.01006';
 }
 
 # ABSTRACT: Github v3 Orgs API
@@ -11,14 +11,6 @@ use Pithub::Orgs::Members;
 use Pithub::Orgs::Teams;
 extends 'Pithub::Base';
 
-sub members {
-    return shift->_create_instance('Pithub::Orgs::Members');
-}
-
-sub teams {
-    return shift->_create_instance('Pithub::Orgs::Teams');
-}
-
 
 sub get {
     my ( $self, %args ) = @_;
@@ -48,6 +40,16 @@ sub list {
 }
 
 
+sub members {
+    return shift->_create_instance('Pithub::Orgs::Members');
+}
+
+
+sub teams {
+    return shift->_create_instance('Pithub::Orgs::Teams');
+}
+
+
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: org' unless $args{org};
@@ -70,7 +72,7 @@ Pithub::Orgs - Github v3 Orgs API
 
 =head1 VERSION
 
-version 0.01005
+version 0.01006
 
 =head1 METHODS
 
@@ -119,6 +121,14 @@ Examples:
 
 =back
 
+=head2 members
+
+Provides access to L<Pithub::Orgs::Members>.
+
+=head2 teams
+
+Provides access to L<Pithub::Orgs::Teams>.
+
 =head2 update
 
 =over
