@@ -1,6 +1,6 @@
 package Pithub::PullRequests;
 BEGIN {
-  $Pithub::PullRequests::VERSION = '0.01005';
+  $Pithub::PullRequests::VERSION = '0.01006';
 }
 
 # ABSTRACT: Github v3 Pull Requests API
@@ -10,6 +10,7 @@ use Carp qw(croak);
 use Pithub::PullRequests::Comments;
 extends 'Pithub::Base';
 
+
 sub comments {
     return shift->_create_instance('Pithub::PullRequests::Comments');
 }
@@ -121,10 +122,14 @@ Pithub::PullRequests - Github v3 Pull Requests API
 
 =head1 VERSION
 
-version 0.01005
+version 0.01006
 
 =head1 METHODS
 
+=head2 comments
+
+Provides access to L<Pithub::PullRequests::Comments>.
+
 =head2 commits
 
 =over
