@@ -1,6 +1,6 @@
 package Pithub::Users;
 BEGIN {
-  $Pithub::Users::VERSION = '0.01005';
+  $Pithub::Users::VERSION = '0.01006';
 }
 
 # ABSTRACT: Github v3 Users API
@@ -12,18 +12,16 @@ use Pithub::Users::Followers;
 use Pithub::Users::Keys;
 extends 'Pithub::Base';
 
+
 sub emails {
     return shift->_create_instance('Pithub::Users::Emails');
 }
 
+
 sub followers {
     return shift->_create_instance('Pithub::Users::Followers');
 }
 
-sub keys {
-    return shift->_create_instance('Pithub::Users::Keys');
-}
-
 
 sub get {
     my ( $self, %args ) = @_;
@@ -42,6 +40,11 @@ sub get {
 }
 
 
+sub keys {
+    return shift->_create_instance('Pithub::Users::Keys');
+}
+
+
 sub update {
     my ( $self, %args ) = @_;
     croak 'Missing key in parameters: data (hashref)' unless ref $args{data} eq 'HASH';
@@ -63,10 +66,18 @@ Pithub::Users - Github v3 Users API
 
 =head1 VERSION
 
-version 0.01005
+version 0.01006
 
 =head1 METHODS
 
+=head2 emails
+
+Provides access to L<Pithub::Users::Emails>.
+
+=head2 followers
+
+Provides access to L<Pithub::Users::Followers>.
+
 =head2 get
 
 =over
@@ -95,6 +106,10 @@ Examples:
 
 =back
 
+=head2 keys
+
+Provides access to L<Pithub::Users::Keys>.
+
 =head2 update
 
 =over
